grace

package module
v0.0.0-...-3ea9e6c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 20, 2016 License: MIT Imports: 11 Imported by: 0

README

grace

For any graceful reload with networking service base on TCP, Maybe that is a great and beautiful dream.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewGraceServer

func NewGraceServer(s Server, net, addr string) *graceServer

Types

type Server

type Server interface {
	Serve(l net.Listener)
	Stop()
}

Jump to